This is unreleased documentation for the main (development) branch of crypto-glue.

Zeroizing

Struct Zeroizing 

pub struct Zeroizing<Z>(/* private fields */)
where
    Z: Zeroize;
Zeroizing is a a wrapper for any Z: Zeroize type which implements a Drop handler which zeroizes dropped values.

Implementations

Source

impl<Z> Zeroizing<Z>
where Z: Zeroize,

pub fn new(value: Z) -> Zeroizing<Z>

Move value inside a Zeroizing wrapper which ensures it will be zeroized when it’s dropped.