This is unreleased documentation for the main (development) branch of crypto-glue.

SpkiEncodePublicKey

Trait SpkiEncodePublicKey 

pub trait SpkiEncodePublicKey {
    // Required method
    fn to_public_key_der(&self) -> Result<Document, Error>;

    // Provided methods
    fn to_public_key_pem(
        &self,
        line_ending: LineEnding,
    ) -> Result<String, Error> { ... }
    fn write_public_key_der_file(
        &self,
        path: impl AsRef<Path>,
    ) -> Result<(), Error> { ... }
    fn write_public_key_pem_file(
        &self,
        path: impl AsRef<Path>,
        line_ending: LineEnding,
    ) -> Result<(), Error> { ... }
}
Serialize a public key object to a SPKI-encoded document.

Required Methods

fn to_public_key_der(&self) -> Result<Document, Error>

Serialize a Document containing a SPKI-encoded public key.

Errors

Returns encoding errors specific to the concrete type which impls this trait.

Provided Methods

fn to_public_key_pem(&self, line_ending: LineEnding) -> Result<String, Error>

Serialize this public key as PEM-encoded SPKI with the given LineEnding.

Errors

Returns encoding errors specific to the concrete type which impls this trait.

fn write_public_key_der_file(&self, path: impl AsRef<Path>) -> Result<(), Error>

Write ASN.1 DER-encoded public key to the given path.

Errors

Returns encoding errors specific to the concrete type which impls this trait.

fn write_public_key_pem_file( &self, path: impl AsRef<Path>, line_ending: LineEnding, ) -> Result<(), Error>

Write ASN.1 PEM-encoded public key to the given path.

Errors

Returns encoding errors specific to the concrete type which impls this trait.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl EncodePublicKey for RsaPublicKey

Source

impl<C> EncodePublicKey for PublicKey<C>

Available on crate features alloc and pkcs8 only.
Source

impl<C> EncodePublicKey for VerifyingKey<C>

Available on crate features alloc and pkcs8 only.
Source

impl<D> EncodePublicKey for VerifyingKey<D>
where D: Digest,

Available on crate feature encoding only.

Implementors

Source

impl<D> EncodePublicKey for crypto_glue::rsa::pkcs1v15::VerifyingKey<D>
where D: Digest,

Available on crate feature encoding only.