pub trait SpkiEncodePublicKey {
// Required method
fn to_public_key_der(&self) -> Result<Document, Error>;
// Provided methods
fn to_public_key_pem(
&self,
line_ending: LineEnding,
) -> Result<String, Error> { ... }
fn write_public_key_der_file(
&self,
path: impl AsRef<Path>,
) -> Result<(), Error> { ... }
fn write_public_key_pem_file(
&self,
path: impl AsRef<Path>,
line_ending: LineEnding,
) -> Result<(), Error> { ... }
}Expand description
Serialize a public key object to a SPKI-encoded document.
Required Methods
Provided Methods
Sourcefn to_public_key_pem(&self, line_ending: LineEnding) -> Result<String, Error>
fn to_public_key_pem(&self, line_ending: LineEnding) -> Result<String, Error>
Serialize this public key as PEM-encoded SPKI with the given LineEnding.
Errors
Returns encoding errors specific to the concrete type which impls this trait.
Sourcefn write_public_key_der_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
fn write_public_key_der_file(&self, path: impl AsRef<Path>) -> Result<(), Error>
Write ASN.1 DER-encoded public key to the given path.
Errors
Returns encoding errors specific to the concrete type which impls this trait.
Sourcefn write_public_key_pem_file(
&self,
path: impl AsRef<Path>,
line_ending: LineEnding,
) -> Result<(), Error>
fn write_public_key_pem_file( &self, path: impl AsRef<Path>, line_ending: LineEnding, ) -> Result<(), Error>
Write ASN.1 PEM-encoded public key to the given path.
Errors
Returns encoding errors specific to the concrete type which impls this trait.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl EncodePublicKey for RsaPublicKey
impl EncodePublicKey for RsaPublicKey
Sourceimpl<C> EncodePublicKey for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromSec1Point<C> + ToSec1Point<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate features alloc and pkcs8 only.
impl<C> EncodePublicKey for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromSec1Point<C> + ToSec1Point<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate features
alloc and pkcs8 only.Sourceimpl<C> EncodePublicKey for VerifyingKey<C>where
C: EcdsaCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromSec1Point<C> + ToSec1Point<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate features alloc and pkcs8 only.
impl<C> EncodePublicKey for VerifyingKey<C>where
C: EcdsaCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromSec1Point<C> + ToSec1Point<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate features
alloc and pkcs8 only.Sourceimpl<D> EncodePublicKey for VerifyingKey<D>where
D: Digest,
Available on crate feature encoding only.
impl<D> EncodePublicKey for VerifyingKey<D>where
D: Digest,
Available on crate feature
encoding only.Implementors
impl<D> EncodePublicKey for crypto_glue::rsa::pkcs1v15::VerifyingKey<D>where
D: Digest,
Available on crate feature
encoding only.